@@ -172,27 +172,21 @@ impl License {
 }
 
 macro_rules! gen_context_for_self_action {
-	($self:expr, $raw_args:expr) => {{
+	($raw_args:expr) => {{
 		let mut args = VecDeque::from($raw_args.clone());
 		let exe_path = args.pop_front().unwrap();
-		gen_context_for_self_action!($self, $raw_args, args, exe_path)
+		gen_context_for_self_action!($raw_args, args, exe_path)
 	}};
-	($self:expr,$raw_args:expr,$args:expr,$exe_path:expr) => {
-		Context::new(
-			$raw_args,
-			$args,
-			$self.c_flags.take(),
-			$self.derive_route_init_vector(),
-			$exe_path,
-		)
+	($raw_args:expr,$args:expr,$exe_path:expr) => {
+		Context::new($raw_args, $args, Vector(None), Vector(None), $exe_path)
 	};
-	($self:expr, $raw_args:expr,$args:expr,$exe_path:expr, $inter_mediate_args:expr) => {
+	($raw_args:expr,$args:expr,$exe_path:expr, $inter_mediate_args:expr) => {
 		Context::with_all_field(
 			$raw_args,
 			$args,
-			$self.c_flags.take().into(),
+			Vector(None),
 			$exe_path,
-			$self.derive_route_init_vector(),
+			Vector(None),
 			Vector::default(),
 			Vector::default(),
 			Some($inter_mediate_args),
@@ -202,21 +196,20 @@ macro_rules! gen_context_for_self_action {
 }
 
 macro_rules! gen_context_for_sub_run {
-	($self:expr,$sub:expr, $raw_args:expr,$args:expr,$exe_path:expr) => {
-		gen_context_for_sub_run!(inner, $self, $sub, $raw_args, $args, $exe_path, None)
+	($self:expr,$raw_args:expr,$args:expr,$exe_path:expr) => {
+		gen_context_for_sub_run!(inner, $self, $raw_args, $args, $exe_path, None)
 	};
-	($self:expr,$sub:expr, $raw_args:expr,$args:expr,$exe_path:expr, $inter_mediate_args: expr) => {
+	($self:expr,$raw_args:expr,$args:expr,$exe_path:expr, $inter_mediate_args: expr) => {
 		gen_context_for_sub_run!(
 			inner,
 			$self,
-			$sub,
 			$raw_args,
 			$args,
 			$exe_path,
 			Some($inter_mediate_args)
 		)
 	};
-	(inner,$self:expr, $sub:expr, $raw_args:expr,$args:expr,$exe_path:expr,$inter_mediate_args:expr) => {
+	(inner,$self:expr, $raw_args:expr,$args:expr,$exe_path:expr,$inter_mediate_args:expr) => {
 		Context::with_all_field(
 			$raw_args,
 			$args,
@@ -329,17 +322,18 @@ impl Command {
 		match self.action.take() {
 			Some(action) => {
 				if raw_args.len() < 2 {
-					action(gen_context_for_self_action!(self, raw_args), self)
+					action(gen_context_for_self_action!(raw_args), self)
 				} else {
-					let mut context = gen_context_for_self_action!(self, raw_args);
+					let mut context = gen_context_for_self_action!(raw_args);
 					//println!("single_run_context: {:?}", context);
-					context = Parser::default().parse_args_until_end(&self.l_flags, context);
+					context =
+						Parser::default().parse_args_until_end(&self.l_flags, &self.c_flags, context);
 					action(context, self)
 				}
 			}
 			None => match self.sub {
 				Vector(None) => {
-					let c = gen_context_for_self_action!(self, raw_args);
+					let c = gen_context_for_self_action!(raw_args);
 					no_registered_error!(c)
 				}
 				_ => self.run(raw_args),
@@ -536,7 +530,7 @@ impl Command {
 		let head = args.pop_front();
 		if head.is_none() {
 			//引数がない場合
-			let c = gen_context_for_self_action!(self, raw_args, args, exe_path);
+			let c = gen_context_for_self_action!(raw_args, args, exe_path);
 			match self.action {
 				Some(action) => action(c, self),
 				None => no_registered_error!(c),
@@ -560,18 +554,18 @@ impl Command {
 						None => {
 							// ルートコマンド実行のとき
 							args.push_front(arg);
-							let mut c = gen_context_for_self_action!(self, raw_args, args, exe_path);
+							let mut c = gen_context_for_self_action!(raw_args, args, exe_path);
 							match self.action {
 								None => no_registered_error!(c),
 								Some(action) => {
-									c = p.parse_args_until_end(&self.l_flags, c);
+									c = p.parse_args_until_end(&self.l_flags, &self.c_flags, c);
 									action(c, self)
 								}
 							}
 						}
 						Some(sub) => {
 							// サブコマンドがヒットしたとき
-							let c = gen_context_for_sub_run!(self, sub, raw_args, args, exe_path);
+							let c = gen_context_for_sub_run!(self, raw_args, args, exe_path);
 							let r = sub.run(c);
 							// サブコマンドの結果をハンドリング
 							self.handle_sub_result(r)
@@ -590,27 +584,25 @@ impl Command {
 	pub fn run_with_context(mut self, mut context: Context) -> run_result!() {
 		if self.sub.is_none() {
 			// サブコマンドがない場合
-			context.common_flags.push(self.c_flags.take());
 			let p = Parser::default();
 			let (mut context, non_flag_args) =
-				p.parse_inter_mediate_args(&self.l_flags, context, true);
+				p.parse_inter_mediate_args(&self.l_flags, &self.c_flags, context, true);
 			if let Some(mut non_flag_args) = non_flag_args {
 				non_flag_args.append(&mut context.args);
 				context.args = non_flag_args;
 			}
-			context = p.parse_args_until_end(&self.l_flags, context);
-			context.routes.push(self.name.clone());
+			context = p.parse_args_until_end(&self.l_flags, &self.c_flags, context);
 			match self.action {
 				Some(action) => action(context, self),
 				None => no_registered_error!(context),
 			}
 		} else {
 			//サブコマンドと一致するかを捜査
-			context.routes.push(self.name.clone());
 			let p = Parser::default();
 			match context.args.pop_front() {
 				Some(long_flag) if p.long_flag(&long_flag) => {
 					let last = p.long_middle(long_flag);
+					println!("test1 assign_context");
 					self.assign_context(context, p, VecDeque::new(), last)
 				}
 				Some(short_flag) if p.flag(&short_flag) => {
@@ -623,43 +615,45 @@ impl Command {
 						Some(mut sub) => {
 							context.common_flags.push(self.c_flags.take());
 							check_sub!(sub, self);
-							println!("{:?}", &context);
+							context.routes.push(self.name.clone());
 							let r = sub.run(context);
 							self.handle_sub_result(r)
 						}
-						None => {
-							context.common_flags.push(self.c_flags.take());
-							match self.action {
-								None => no_registered_error!(context),
-								Some(action) => {
-									let c = match p.parse_inter_mediate_args(&self.l_flags, context, true) {
-										(mut context, None) => {
-											context = p.parse_args_until_end(&self.l_flags, context);
-											context.args.push_front(arg);
-											context
-										}
-										(mut context, Some(mut non_flag_args)) => {
-											context = p.parse_args_until_end(&self.l_flags, context);
-											context.args.push_front(arg);
-											non_flag_args.append(&mut context.args);
-											context.args = non_flag_args;
-											context
-										}
-									};
-									action(c, self)
-								}
+						None => match self.action {
+							None => no_registered_error!(context),
+							Some(action) => {
+								let c = match p.parse_inter_mediate_args(
+									&self.l_flags,
+									&self.c_flags,
+									context,
+									true,
+								) {
+									(mut context, None) => {
+										context =
+											p.parse_args_until_end(&self.l_flags, &self.c_flags, context);
+										context.args.push_front(arg);
+										context
+									}
+									(mut context, Some(mut non_flag_args)) => {
+										context =
+											p.parse_args_until_end(&self.l_flags, &self.c_flags, context);
+										context.args.push_front(arg);
+										non_flag_args.append(&mut context.args);
+										context.args = non_flag_args;
+										context
+									}
+								};
+								action(c, self)
 							}
-						}
+						},
 					}
 				}
 				None => {
 					//サブコマンド等の処理の必要がないのでこのまま叩き込む
 					match self.action {
 						Some(action) => {
-							context.common_flags.push(self.c_flags.take());
-
 							let (mut context, non_flag_args) =
-								p.parse_inter_mediate_args(&self.l_flags, context, true);
+								p.parse_inter_mediate_args(&self.l_flags, &self.c_flags, context, true);
 							if let Some(mut non_flag_args) = non_flag_args {
 								non_flag_args.append(&mut context.args);
 								context.args = non_flag_args;
@@ -667,10 +661,8 @@ impl Command {
 							action(context, self)
 						}
 						None => {
-							context.common_flags.push(self.c_flags.take());
-
 							let (mut context, non_flag_args) =
-								p.parse_inter_mediate_args(&self.l_flags, context, true);
+								p.parse_inter_mediate_args(&self.l_flags, &self.c_flags, context, true);
 							if let Some(mut non_flag_args) = non_flag_args {
 								non_flag_args.append(&mut context.args);
 								context.args = non_flag_args;
@@ -710,6 +702,7 @@ impl Command {
 						c.parsing_args = Some(inter_mediate_args);
 					}
 					check_sub!(sub, self);
+					c.routes.push(self.name.clone());
 					let r = sub.run(c);
 					self.handle_sub_result(r)
 				}
@@ -738,6 +731,7 @@ impl Command {
 									} else {
 										c.parsing_args = Some(inter_mediate_args);
 									}
+									c.routes.push(self.name.clone());
 									check_sub!(sub, self);
 									let r = sub.run(c);
 									self.handle_sub_result(r)
@@ -749,10 +743,9 @@ impl Command {
 									} else {
 										c.parsing_args = Some(inter_mediate_args);
 									}
-									c.common_flags.push(self.c_flags.take());
 									let (mut c, non_flag_args) =
-										p.parse_inter_mediate_args(&self.l_flags, c, false);
-									c = p.parse_args_until_end(&self.l_flags, c);
+										p.parse_inter_mediate_args(&self.l_flags, &self.c_flags, c, false);
+									c = p.parse_args_until_end(&self.l_flags, &self.c_flags, c);
 									c.args.push_front(arg);
 									if let Some(mut non_flag_args) = non_flag_args {
 										non_flag_args.append(&mut c.args);
@@ -771,7 +764,8 @@ impl Command {
 								} else {
 									c.parsing_args = Some(inter_mediate_args);
 								}
-								let (mut c, args) = p.parse_inter_mediate_args(&self.l_flags, c, false);
+								let (mut c, args) =
+									p.parse_inter_mediate_args(&self.l_flags, &self.c_flags, c, false);
 
 								if let Some(mut args) = args {
 									args.append(&mut c.args);
@@ -787,13 +781,13 @@ impl Command {
 					_ => {
 						inter_mediate_args.push_back(last);
 						c.args = args;
-						c.common_flags.push(self.c_flags.take());
 						if let Some(mut parsing_args) = c.parsing_args {
 							parsing_args.append(&mut inter_mediate_args);
 							c.parsing_args = Some(parsing_args);
 						}
-						let (mut c, non_flag_args) = p.parse_inter_mediate_args(&self.l_flags, c, false);
-						c = p.parse_args_until_end(&self.l_flags, c);
+						let (mut c, non_flag_args) =
+							p.parse_inter_mediate_args(&self.l_flags, &self.c_flags, c, false);
+						c = p.parse_args_until_end(&self.l_flags, &self.c_flags, c);
 						c.args.push_front(arg);
 						if let Some(mut non_flag_args) = non_flag_args {
 							non_flag_args.append(&mut c.args);
@@ -815,8 +809,8 @@ impl Command {
 				} else {
 					c.parsing_args = Some(inter_mediate_args);
 				}
-				c.common_flags.push(self.c_flags.take());
-				let (mut c, non_flag_args) = p.parse_inter_mediate_args(&self.l_flags, c, false);
+				let (mut c, non_flag_args) =
+					p.parse_inter_mediate_args(&self.l_flags, &self.c_flags, c, false);
 				//println!("after_parse_ima:{:?}", c);
 				if let Some(non_flag_args) = non_flag_args {
 					//non_flag_args.append(&mut c.args);
@@ -850,14 +844,9 @@ impl Command {
 				match self.take_sub(&arg) {
 					Some(sub) => {
 						inter_mediate_args.push_back(last);
-						let c = gen_context_for_sub_run!(
-							self,
-							sub,
-							raw_args,
-							args,
-							exe_path,
-							inter_mediate_args
-						);
+						let c =
+							gen_context_for_sub_run!(self, raw_args, args, exe_path, inter_mediate_args);
+						println!("test0 {:?}", &c);
 						let r = sub.run(c);
 						r
 					}
@@ -882,7 +871,6 @@ impl Command {
 										Some(sub) => {
 											let c = gen_context_for_sub_run!(
 												self,
-												sub,
 												raw_args,
 												args,
 												exe_path,
@@ -894,15 +882,18 @@ impl Command {
 										None => {
 											//サブコマンドはないのでそのままselfでaction
 											let c = gen_context_for_self_action!(
-												self,
 												raw_args,
 												args,
 												exe_path,
 												inter_mediate_args
 											);
-											let (mut c, non_flag_args) =
-												p.parse_inter_mediate_args(&self.l_flags, c, false);
-											c = p.parse_args_until_end(&self.l_flags, c);
+											let (mut c, non_flag_args) = p.parse_inter_mediate_args(
+												&self.l_flags,
+												&self.c_flags,
+												c,
+												false,
+											);
+											c = p.parse_args_until_end(&self.l_flags, &self.c_flags, c);
 											c.args.push_front(arg);
 											if let Some(mut non_flag_args) = non_flag_args {
 												non_flag_args.append(&mut c.args);
@@ -917,14 +908,13 @@ impl Command {
 									None => {
 										//残りのargはなし、そのままaction
 										let c = gen_context_for_self_action!(
-											self,
 											raw_args,
 											args,
 											exe_path,
 											inter_mediate_args
 										);
 										let (mut c, non_flag_args) =
-											p.parse_inter_mediate_args(&self.l_flags, c, false);
+											p.parse_inter_mediate_args(&self.l_flags, &self.c_flags, c, false);
 										if let Some(mut non_flag_args) = non_flag_args {
 											non_flag_args.append(&mut c.args);
 											c.args = non_flag_args;
@@ -942,15 +932,14 @@ impl Command {
 								//inter_mediate_args.push_back(MiddleArg::Normal(arg));
 
 								let c = gen_context_for_self_action!(
-									self,
 									raw_args,
 									args,
 									exe_path,
 									inter_mediate_args
 								);
 								let (mut c, non_flag_args) =
-									p.parse_inter_mediate_args(&self.l_flags, c, false);
-								c = p.parse_args_until_end(&self.l_flags, c);
+									p.parse_inter_mediate_args(&self.l_flags, &self.c_flags, c, false);
+								c = p.parse_args_until_end(&self.l_flags, &self.c_flags, c);
 								c.args.push_front(arg);
 								if let Some(mut non_flag_args) = non_flag_args {
 									non_flag_args.append(&mut c.args);
@@ -970,8 +959,9 @@ impl Command {
 				//self.actionに放り込む
 				inter_mediate_args.push_back(last);
 				let context =
-					gen_context_for_self_action!(self, raw_args, args, exe_path, inter_mediate_args);
-				let (mut c, non_flag_args) = p.parse_inter_mediate_args(&self.l_flags, context, false);
+					gen_context_for_self_action!(raw_args, args, exe_path, inter_mediate_args);
+				let (mut c, non_flag_args) =
+					p.parse_inter_mediate_args(&self.l_flags, &self.c_flags, context, false);
 				if let Some(mut non_flag_args) = non_flag_args {
 					non_flag_args.append(&mut c.args);
 					c.args = non_flag_args;
@@ -1070,7 +1060,7 @@ mod tests {
 				assert_eq!(c.raw_args, raw_args);
 				assert_eq!(c.args, expect_args);
 				assert_eq!(c.exe_path, String::from("exe_path"));
-				assert_eq!(c.routes, Vector(Some(vec!["root".to_string()])));
+				assert_eq!(c.routes, Vector(None));
 				let l_flag_values = Vector::from(vec![
 					(
 						"local".to_string(),
@@ -1497,7 +1487,7 @@ mod tests {
 				);
 				assert_eq!(c.get_flag_value_of("commons", &cmd), None);
 				assert_eq!(c.get_flag_value_of("local", &cmd), None);
-				assert_eq!(c.routes, "sub".to_owned().into());
+				assert_eq!(c.routes, Vector(None));
 				assert_attrs!("sub_", c, cmd);
 				done!()
 			}))
@@ -1522,10 +1512,7 @@ mod tests {
 					c.get_flag_value_of("bool", &cmd).unwrap(),
 					FlagValue::Bool(true)
 				);
-				assert_eq!(
-					c.routes,
-					Vector(Some(vec!["root".to_string(), "sub".to_string()]))
-				);
+				assert_eq!(c.routes, Vector(Some(vec!["root".to_string()])));
 				assert_attrs!("sub_", c, cmd);
 				done!()
 			}))
@@ -1551,7 +1538,7 @@ mod tests {
 					c.get_flag_value_of("bool", &cmd).unwrap(),
 					FlagValue::Bool(true)
 				);
-				assert_eq!(c.routes, Vector(Some(vec!["sub".to_string()])));
+				assert_eq!(c.routes, Vector(None));
 				assert_attrs!("sub_", c, cmd);
 				done!()
 			}))
@@ -1600,7 +1587,7 @@ mod tests {
 					c.get_flag_value_of("string", &cmd).unwrap(),
 					FlagValue::String("testStr".into())
 				);
-				assert_eq!(c.routes, Vector(Some(vec!["sub".to_string()])));
+				assert_eq!(c.routes, Vector(None));
 				assert_attrs!("sub_", c, cmd);
 				done!()
 			}))
@@ -1627,7 +1614,7 @@ mod tests {
 				);
 				assert_eq!(c.args, vec!["test_arg2".to_string()]);
 				assert_eq!(
-					c.get_common_flag_value_of("cstr").unwrap(),
+					c.get_common_flag_value_of("cstr", &cmd).unwrap(),
 					FlagValue::String("test".into())
 				);
 				assert_eq!(
@@ -1638,7 +1625,7 @@ mod tests {
 					c.get_inputted_common_flag_value_of("cafter").unwrap(),
 					FlagValue::None
 				);
-				assert_eq!(c.routes, Vector(Some(vec!["sub".to_string()])));
+				assert_eq!(c.routes, Vector(None));
 				assert_attrs!("sub_", c, cmd);
 				done!()
 			}))
@@ -1666,7 +1653,7 @@ mod tests {
 					])
 				);
 				assert_eq!(c.args, cnv_arg(vec!["test_arg", "ex_arg"]));
-				assert_eq!(c.routes, Vector(Some(vec!["sub".to_string()])));
+				assert_eq!(c.routes, Vector(None));
 				assert_attrs!("sub_", c, cmd);
 				done!()
 			}))
@@ -1708,7 +1695,7 @@ mod tests {
 					]
 				);
 				assert_eq!(
-					c.get_common_flag_value_of("cstr").unwrap(),
+					c.get_common_flag_value_of("cstr", &cmd).unwrap(),
 					FlagValue::String("test".into())
 				);
 				assert_eq!(
@@ -1716,14 +1703,14 @@ mod tests {
 					FlagValue::Bool(true)
 				);
 				assert_eq!(
-					c.get_common_flag_value_of("cafter").unwrap(),
+					c.get_common_flag_value_of("cafter", &cmd).unwrap(),
 					FlagValue::Bool(true)
 				);
 				assert_eq!(
 					c.get_flag_value_of("string", &cmd).unwrap(),
 					FlagValue::String("testStr".into())
 				);
-				assert_eq!(c.routes, Vector(Some(vec!["sub".to_string()])));
+				assert_eq!(c.routes, Vector(None));
 				assert_attrs!("sub_", c, cmd);
 				done!()
 			}))
@@ -1771,7 +1758,7 @@ mod tests {
 					c.get_flag_value_of("common", &cmd).unwrap(),
 					FlagValue::Bool(true)
 				);
-				assert_eq!(c.routes, Vector(Some(vec!["sub".to_string()])));
+				assert_eq!(c.routes, Vector(None));
 				assert_attrs!("sub_", c, cmd);
 				done!()
 			}))
@@ -1845,11 +1832,8 @@ mod tests {
 									c.get_flag_value_of("local", &cmd).unwrap(),
 									FlagValue::Bool(true)
 								);
-								assert_eq!(c.get_common_flag_value_of("local"), None);
-								assert_eq!(
-									c.routes,
-									Vector(Some(vec!["sub".to_string(), "leaf".to_string()]))
-								);
+								assert_eq!(c.get_common_flag_value_of("local", &cmd), None);
+								assert_eq!(c.routes, Vector(Some(vec!["sub".to_string()])));
 								assert_attrs!("leaf_", c, cmd);
 								done!()
 							})
@@ -1923,11 +1907,7 @@ mod tests {
 				);
 				assert_eq!(
 					c.routes,
-					Vector(Some(vec![
-						"root".to_string(),
-						"sub".to_owned(),
-						"leaf".to_owned()
-					]))
+					Vector(Some(vec!["root".to_string(), "sub".to_owned(),]))
 				);
 				assert_attrs!("leaf_", c, cmd);
 				done!()
@@ -1963,10 +1943,7 @@ mod tests {
 					c.get_flag_value_of("lsbefore", &cmd).unwrap(),
 					FlagValue::String("".into())
 				);
-				assert_eq!(
-					c.routes,
-					Vector(Some(vec!["sub".to_owned(), "leaf".to_owned()]))
-				);
+				assert_eq!(c.routes, Vector(Some(vec!["sub".to_owned()])));
 				assert_attrs!("leaf_", c, cmd);
 				done!()
 			},
@@ -2004,10 +1981,7 @@ mod tests {
 					c.get_flag_value_of("cbool", &cmd).unwrap(),
 					FlagValue::Bool(true)
 				);
-				assert_eq!(
-					c.routes,
-					Vector(Some(vec!["sub".to_owned(), "leaf".to_owned()]))
-				);
+				assert_eq!(c.routes, Vector(Some(vec!["sub".to_owned()])));
 				assert_attrs!("leaf_", c, cmd);
 				done!()
 			},
@@ -2044,10 +2018,7 @@ mod tests {
 					c.get_flag_value_of("lsbefore", &cmd).unwrap(),
 					FlagValue::String("before_arg".into())
 				);
-				assert_eq!(
-					c.routes,
-					Vector(Some(vec!["sub".to_owned(), "leaf".to_owned()]))
-				);
+				assert_eq!(c.routes, Vector(Some(vec!["sub".to_owned()])));
 				assert_attrs!("leaf_", c, cmd);
 				done!()
 			},
@@ -2188,36 +2159,35 @@ pub mod presets {
 				if let Vector(Some(short_alias)) = &f.short_alias {
 					for s in short_alias.iter() {
 						if !$s_list.contains(&s) {
+							if (!all_dup) {
+								$help.push(',');
+							}
 							all_dup = false;
 							$help.push_str("-");
 							$help.push(*s);
-							$help.push(',');
 							$s_list.push(s);
 						}
 					}
 				} else {
 					$help.push_str(&$indent);
 				}
-				let mut name_dup = true;
 				if !$nl_list.contains(&&f.name) {
+					$help.push_str(if all_dup { " --" } else { ", --" });
 					all_dup = false;
-					name_dup = false;
-					$help.push_str(" --");
 					$help.push_str(&f.name);
 					$nl_list.push(&f.name);
 				}
 				if let Vector(Some(long_alias)) = &f.long_alias {
 					for long in long_alias.iter() {
 						if !$nl_list.contains(&long) {
-							all_dup = false;
 							$nl_list.push(long);
-							if name_dup {
+							if all_dup {
 								$help.push_str(" --");
-								$help.push_str(long);
+								all_dup = false;
 							} else {
 								$help.push_str(", --");
-								$help.push_str(long);
 							}
+							$help.push_str(long);
 						}
 					}
 				}
@@ -2285,7 +2255,7 @@ pub mod presets {
 			}
 		}
 
-		// コモンフラグ出力(cmdに残っているフラグ)
+		// コモンフラグ出力(cmdに残っているフラグを出力)
 		let mut routes = ctx.routes.clone();
 		if let Vector(Some(c_flags)) = &cmd.c_flags {
 			let emp_str = String::new();
@@ -2301,17 +2271,21 @@ pub mod presets {
 			);
 			routes.pop();
 		}
-		if routes.len() < ctx.common_flags.len() {
+		let mut routes: Vec<String> = if routes.len() < ctx.common_flags.len() {
+			let mut routes: Vec<String> = routes.into();
 			routes.insert(
 				0,
-				std::path::Path::new(&ctx.exe_path)
+				std::path::Path::new(ctx.exe_path())
 					.file_stem()
 					.unwrap_or(std::ffi::OsStr::new("root"))
 					.to_str()
 					.unwrap_or("root")
 					.to_owned(),
 			);
-		}
+			routes
+		} else {
+			routes.into()
+		};
 		// コモンフラグ出力(contextに取り込まれているフラグ)
 		if let Vector(Some(cfs)) = &ctx.common_flags {
 			let self_common_index = cfs.len() - 1;
@@ -2370,11 +2344,49 @@ pub mod presets {
 				help += "\n";
 
 				for sub_cmd in iter {
+					let mut all_dup = true;
+					let help_first_width = help.len();
 					if !na_list.contains(&&sub_cmd.name) {
-						na_list.push(&sub_cmd.name)
+						na_list.push(&sub_cmd.name);
+						help = help + &indent + &sub_cmd.name;
+						all_dup = false;
+					}
+					if let Vector(Some(alias)) = &sub_cmd.alias {
+						for a in alias {
+							if !na_list.contains(&a) {
+								na_list.push(a);
+								if all_dup {
+									help = help + &indent + a;
+								} else {
+									help = help + ", " + a;
+								}
+								all_dup = false;
+							}
+						}
+					}
+					if !all_dup {
+						let name_and_alias_width = help_first_width - help.len();
+						if name_and_alias_width < name_and_alias_min_width {
+							help += &sp.repeat(name_and_alias_min_width - name_and_alias_width);
+						}
+						if let Some(description) = &sub_cmd.description {
+							help = help + "\t" + description;
+						}
+						help += "\n"
 					}
 				}
 			}
+			if routes.len() < 2 && !cmd.name.is_empty() {
+				routes[0] = cmd.name.clone();
+			}
+			let exe_suffix = std::env::consts::EXE_SUFFIX;
+			if !exe_suffix.is_empty() {
+				routes[0].push_str("[");
+				routes[0].push_str(exe_suffix);
+				routes[0].push_str("]")
+			}
+			help = help + &routes.join(" ") + "<subcommand> --help for more information.";
+			help += "\n";
 		}
 
 		return help;
@@ -2450,7 +2462,7 @@ pub mod presets {
 								let mut from_owned: String;
 								let from = if route_without_root {
 									if index < 1 {
-										let cur_path = std::path::Path::new(ctx.current());
+										let cur_path = std::path::Path::new(ctx.exe_path());
 										from_owned = cur_path
 											.file_stem()
 											.unwrap_or(std::ffi::OsStr::new("root"))
@@ -2535,7 +2547,7 @@ pub mod presets {
 			let loc_owned: String;
 			let location: &str = {
 				if cmd.name.is_empty() {
-					let path = std::path::Path::new(ctx.current());
+					let path = std::path::Path::new(ctx.exe_path());
 					let mut l: String = path
 						.file_stem()
 						.unwrap_or(std::ffi::OsStr::new("root"))
@@ -2560,7 +2572,7 @@ pub mod presets {
 							routes.iter().rfold(
 								{
 									if depth > routes.len() {
-										let path = std::path::Path::new(ctx.current());
+										let path = std::path::Path::new(ctx.exe_path());
 										let mut l = path
 											.file_stem()
 											.unwrap_or(std::ffi::OsStr::new("root"))
